@@ -11,7 +11,7 @@ use strict;
 
 package Curses::Toolkit::Widget;
 BEGIN {
-  $Curses::Toolkit::Widget::VERSION = '0.206';
+  $Curses::Toolkit::Widget::VERSION = '0.207';
 }
 
 # ABSTRACT: base class for widgets
@@ -317,11 +317,17 @@ sub get_visible_shape {
     my $shape  = $self->get_coordinates->clone;
     my $parent = $self->get_parent;
     defined $parent
-        and $shape->restrict_to( $parent->get_visible_shape );
+        and $shape->restrict_to( $parent->get_visible_shape_for_children );
     return $shape;
 }
 
 
+sub get_visible_shape_for_children {
+    my ($self) = @_;
+    return $self->get_visible_shape();
+}
+
+
 sub rebuild_all_coordinates {
     my ($self) = @_;
     my $widget = $self;
@@ -352,7 +358,7 @@ sub needs_redraw {
 }
 
 # sets the relatives coordinates, from the origin of the parent widget
-#  input  : any Curses::Toolkit::Object::Coordinates costructor input
+#  input  : any Curses::Toolkit::Object::Coordinates constructor input
 #  output : the widget
 sub _set_relatives_coordinates {
     my $self = shift;
@@ -361,6 +367,14 @@ sub _set_relatives_coordinates {
     return $self;
 }
 
+# gets the relatives coordinates, from the origin of the parent widget
+#  input  : none
+#  output : Curses::Toolkit::Object::Coordinates
+sub _get_relatives_coordinates {
+    my ($self) = @_;
+    return $self->{relatives_coordinates};
+}
+
 # Sets the Curses object to the widget.
 #
 #  input  : a Curses object
@@ -615,7 +629,7 @@ Curses::Toolkit::Widget - base class for widgets
 
 =head1 VERSION
 
-version 0.206
+version 0.207
 
 =head1 DESCRIPTION
 
@@ -835,6 +849,15 @@ Gets the Coordinates of the part of the widget which is visible
   input  : none
   output : the shape (Curses::Toolkit::Object::Coordinates) or void
 
+=head2 get_visible_shape_for_children
+
+Gets the Coordinates of the part of the widget which is visible and that its
+children can draw on. By default it's the same as get_visible_shape, but it may
+be overloaded to reduce it some time (for instance if the widget has borders)
+
+  input  : none
+  output : the shape (Curses::Toolkit::Object::Coordinates) or void
+
 =head2 rebuild_all_coordinates
 
   $widget->rebuild_all_coordinates();
